@@ -7,6 +7,7 @@ from copy import deepcopy
 from tqdm.autonotebook import tqdm
 from multiprocessing import Process, Manager, Queue, Pool, Array
 from time import sleep
+import psutil
 
 from medcat.cdb import CDB
 from medcat.preprocessing.tokenizers import spacy_split_all
@@ -719,13 +720,13 @@ class CAT(object):
         return json.dumps(out)
 
 
-    def multiprocessing(self, in_data, nproc=8, batch_size_chars=1000000, max_chars_in_memory=-1, only_cui=False, addl_info=[]):
+    def multiprocessing(self, in_data, nproc=8, batch_size_chars=1000000, max_ram_percentage=-1, only_cui=False, addl_info=[]):
         r''' Run multiprocessing NOT FOR TRAINING
 
         in_data:  an iterator or array with format: [(id, text), (id, text), ...]
         nproc:  number of processors
         batch_size_chars: size of a batch in number of characters
-        max_chars_in_memory: if set it will limit the number of chars that can be processed together by all processed combined 
+        max_ram_percentage: maximum utilzation of RAM when running many processes, if it is more, it will pause until some processes are done 
 
         return:  an list of tuples: [(id, doc_json), (id, doc_json), ...]
         '''
@@ -739,13 +740,12 @@ class CAT(object):
         manager = Manager()
         out_dict = manager.dict()
         out_dict['processed'] = []
-        out_dict['current_size_in_chars'] = 0
 
         # Create processes
         procs = []
         for i in range(nproc):
             p = Process(target=self._mp_cons, kwargs={'in_q': in_q, 'out_dict': out_dict, 'pid': i, 'only_cui': only_cui,
-                'addl_info': addl_info, 'max_chars_in_memory': max_chars_in_memory})
+                'addl_info': addl_info, 'max_ram_percentage': max_ram_percentage})
             p.start()
             procs.append(p)
 
@@ -784,7 +784,7 @@ class CAT(object):
         return out
 
 
-    def _mp_cons(self, in_q, out_dict, pid=0, only_cui=False, addl_info=[], max_chars_in_memory=-1):
+    def _mp_cons(self, in_q, out_dict, pid=0, only_cui=False, addl_info=[], max_ram_percentage=-1):
         cnt = 0
         out = []
         while True:
@@ -796,34 +796,17 @@ class CAT(object):
 
                 for id, text in data:
                     try:
-                        if max_chars_in_memory > 0:
-                            cnt = 0
-                            while (out_dict['current_size_in_chars'] + len(text)) > max_chars_in_memory:
-                                cnt += 1
-                                self.log.debug("Process: {}, waiting because current chars in memory: {}".format(pid, out_dict['current_size_in_chars']))
-                                # Wait until size in memory is low
-                                sleep(3)
-                                if cnt % 200 == 0:
-                                    self.log.info("Process: {}, waiting because current chars in memory: {}, cnt: {}".format(
-                                        pid, out_dict['current_size_in_chars'], cnt))
-                                if cnt % 2000 == 0:
-                                    self.log.info("Breaking out: {} - a stuck process because current chars in memory: {}, cnt: {}".format(
-                                        pid, out_dict['current_size_in_chars'], cnt))
-                                    # Reset, probably something went wrong somewhere
-                                    out_dict['current_size_in_chars'] = 0
-                                    break
-                        out_dict['current_size_in_chars'] = out_dict['current_size_in_chars'] + len(text)
-                        self.log.debug("Process: {}, current chars in memory (before) is: {}".format(pid, out_dict['current_size_in_chars']))
+                        if max_ram_percentage > 0:
+                            while psutil.virtual_memory().percent > max_ram_percentage:
+                                self.log.debug("Process: {}, waiting because current RAM usage: {}".format(pid, psutil.virtual_memory().percent)
+                                sleep(30)
+
                         # Annotate document
                         doc = self.get_entities(text=text, only_cui=only_cui, addl_info=addl_info)
-
-                        out_dict['current_size_in_chars'] = out_dict['current_size_in_chars'] - len(text)
-                        self.log.debug("Process: {}, current chars in memory (after) is: {}".format(pid, out_dict['current_size_in_chars']))
                         doc['text'] = text
                         out.append((id, doc))
                     except Exception as e:
                         self.log.warning("Exception in _mp_cons")
                         self.log.warning(e, stack_info=True)
-                        out_dict['current_size_in_chars'] = out_dict['current_size_in_chars'] - len(text)
 
             sleep(1)
